@@ -10,6 +10,8 @@
 
 #include <KHistoryComboBox>
 #include <KUriFilter>
+#include <KParts/SelectorInterface>
+
 #include <konq_kpart_plugin.h>
 
 #include <QStringList>
@@ -177,6 +179,8 @@ private Q_SLOTS:
 
     void HTMLDocLoaded();
 
+    void insertOpenSearchEntries(const QList<KParts::SelectorInterface::Element> &elements);
+
     void openSearchEngineAdded(const QString &name, const QString &searchUrl, const QString &fileName);
 
     void webShortcutSet(const QString &name, const QString &webShortcut, const QString &fileName);
