@@ -248,6 +248,19 @@ public:
         return s_lstMainWindows;
     }
 
+    /**
+     * @brief A list of all existing `KonqMainWindow`
+     *
+     * @return A list of all `KonqMainWindow`. This list can be empty
+     * @note This function is similar to mainWindowList(). The only differences is that it doesn't return a pointer,
+     * so there's no need to check for `nullptr`, and that the list can't be modified.
+     * @internal The returned list is `const` to avoid the fact that modifying it would affect ::s_lstMainWindows, but
+     * only if the latter isn't `nullptr`, which could be confusing for the user.
+     * @todo Check whether it's possible to make `s_lstMainWindows` not be a pointer: in this case, this function can be
+     * removed and mainWindowList() can be used in its place.
+     */
+    static QList<KonqMainWindow*> const mainWindows() {return s_lstMainWindows ? *s_lstMainWindows : QList<KonqMainWindow*>{};}
+
     void linkableViewCountChanged();
     void viewCountChanged();
 
@@ -309,9 +322,28 @@ public:
 
     bool isPreloaded() const;
 
+    /**
+     * @brief The index of the current tab
+     * @return the index of the current tab
+     */
+    int currentTabIndex() const;
+
+    /**
+     * @brief The number of tabs
+     * @return the number of tabs
+     */
+    int tabsCount() const;
+
     // Public for unit tests
     void prepareForPopupMenu(const KFileItemList &items, const KParts::OpenUrlArguments &args, const KParts::BrowserArguments &browserArgs);
 
+    /**
+     * @brief The last time the window was deactivated
+     *
+     * @return the last time the window was deactivated, as milliseconds from Epoch. If the window was never deactivated, this is 0
+     */
+    qint64 lastDeactivationTime() const;
+
 Q_SIGNALS:
     void viewAdded(KonqView *view);
     void viewRemoved(KonqView *view);
@@ -320,6 +352,8 @@ Q_SIGNALS:
 public Q_SLOTS:
     void updateViewModeActions();
 
+    void activateTab(int index);
+
     void slotInternalViewModeChanged();
 
     void slotCtrlTabPressed();
@@ -744,6 +778,9 @@ private: // members
     */
     bool m_isPopupWithProxyWindow;
     QPointer<KonqMainWindow> m_popupProxyWindow;
+
+    //The last time the window was deactivated, stored as millisecond from epoch
+    qint64 m_lastDeactivationTime = 0;
     
     friend class KonqBrowserInterface;
 };
